pySAXS — pySAXS 77.September2012 documentation

### Navigation

- index
- modules |
- next |
- pySAXS 77.September2012 documentation »

# pySAXS

Python package for Small Angle X-ray Scattering data acquisition, treatment and computation of model SAXS intensities

Main authors: | Olivier Tache, Antoine Thill, Olivier Spalla, David Carriere, Debasis Sen, Fabienne Testard Laboratoire Interdisciplinaire sur l’Organisation Nanometrique et Supramoleculaire (L.I.O.N.S.)
licence: | under CECILL License (consult LICENSE.txt)
website: | http://www-iramis.cea.fr/sis2m/lions

# Welcome to pySAXS’s documentation!

Contents:

- pySAXS
  - pySAXS Package
    - `pySAXS` Package
    - Subpackages
      - LS Package
      - examples Package
      - guisaxs Package
      - models Package
      - tools Package
      - xraylib Package
- LSsca module
  - `pySAXS.LS.LSsca` Module

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- pySAXS 77.September2012 documentation »